==> openshift-model-operator-6.7.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/StorageListBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class StorageListBuilder extends StorageListFluentImpl<StorageListBuilder> implements VisitableBuilder<StorageList,StorageListBuilder>{
  public StorageListBuilder() {
    this(false);
  }
  public StorageListBuilder(Boolean validationEnabled) {
    this(new StorageList(), validationEnabled);
  }
  public StorageListBuilder(StorageListFluent<?> fluent) {
    this(fluent, false);
  }
  public StorageListBuilder(StorageListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new StorageList(), validationEnabled);
  }
  public StorageListBuilder(StorageListFluent<?> fluent,StorageList instance) {
    this(fluent, instance, false);
  }
  public StorageListBuilder(StorageListFluent<?> fluent,StorageList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public StorageListBuilder(StorageList instance) {
    this(instance,false);
  }
  public StorageListBuilder(StorageList instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  StorageListFluent<?> fluent;
  Boolean validationEnabled;
  public StorageList build() {
    StorageList buildable = new StorageList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-operator-6.8.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/StorageListBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class StorageListBuilder extends StorageListFluent<StorageListBuilder> implements VisitableBuilder<StorageList,StorageListBuilder>{
  public StorageListBuilder() {
    this(false);
  }
  public StorageListBuilder(Boolean validationEnabled) {
    this(new StorageList(), validationEnabled);
  }
  public StorageListBuilder(StorageListFluent<?> fluent) {
    this(fluent, false);
  }
  public StorageListBuilder(StorageListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new StorageList(), validationEnabled);
  }
  public StorageListBuilder(StorageListFluent<?> fluent,StorageList instance) {
    this(fluent, instance, false);
  }
  public StorageListBuilder(StorageListFluent<?> fluent,StorageList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new StorageList());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public StorageListBuilder(StorageList instance) {
    this(instance,false);
  }
  public StorageListBuilder(StorageList instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new StorageList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  StorageListFluent<?> fluent;
  Boolean validationEnabled;
  public StorageList build() {
    StorageList buildable = new StorageList(fluent.getApiVersion(),fluent.buildItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
